package models;

import java.util.List;

import models.control.AnimalControl;
import models.control.EmployeeControl;
import models.control.ProcedureControl;
import models.entities.Animal;
import models.entities.Employee;
import models.entities.Procedure;
import models.factory.AbstractFactory;
import models.factory.FactoryBD;

public class VetSofFacade {

	private ProcedureControl procedureControl;
	private AnimalControl animalControl;
	private EmployeeControl employeeControl;
	private AbstractFactory factory;
	
	private static VetSofFacade instance;
	
	public VetSofFacade() {
		factory = new FactoryBD();
		procedureControl = new ProcedureControl(factory);
		animalControl = new AnimalControl(factory);
		employeeControl = new EmployeeControl(factory);
	}
	
	public static VetSofFacade getInstance() {
		if(instance == null) {
			instance = new VetSofFacade();
		}
		return instance;
	}
	
	public void createProcedure(Procedure procedure) {
		procedureControl.create(procedure);
	}

	public void removeProcedure(Long id) {
		procedureControl.remove(id);
	}

	public void updateProcedure(Procedure procedure) {
		procedureControl.update(procedure);
	}

	public List<Procedure> allProcedures() {
		return procedureControl.all();
	}

	public Procedure findProcedureById(Long id) {
		return procedureControl.findProcedureById(id);
	}
	
	public void createAnimal(Animal animal) {
		animalControl.create(animal);
	}
	
	public List<Animal> allAnimals() {
		return animalControl.all();
	}

	public Animal findAnimalById(Long id) {
		return animalControl.findAnimalById(id);
	}
	
	public void createEmployee(Employee employee) {
		employeeControl.create(employee);
	}
	
	public List<Employee> allEmployees() {
		return employeeControl.all();
	}

	public Employee findEmployeeById(Long id) {
		return employeeControl.findEmployeeById(id);
	}
}
