package models.entities;

import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;

import play.db.ebean.Model;

@Entity
public class Procedure extends Model implements Subject {

	@Id
	@GeneratedValue(strategy=GenerationType.SEQUENCE)
	private long id;
	
	private String procedureType;
	private String description;
	private Employee doctor;
	private Employee auxiliar;
	private Animal animal;
	private Date dateProcedure;
	private boolean notified;
	private List<Observer> observers = new ArrayList<Observer>();
	
	public Procedure(String type, String description, Employee responsible, Employee auxiliar, Animal animal, Date date) {
		this.procedureType = type;
		this.description = description;
		this.doctor = responsible;
		this.auxiliar = auxiliar;
		this.animal = animal;
		this.setDateProcedure(date);
		
		this.observers.add(responsible);
		this.observers.add(auxiliar);
	}
	
	
	public long getId() {
		return id;
	}
	
	public String getProcedureType() {
		return procedureType;
	}
	public void setProcedureType(String procedureType) {
		this.procedureType = procedureType;
	}
	
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	
	public Employee getDoctor() {
		return doctor;
	}
	public void setDoctor(Employee doctor) {
		this.doctor = doctor;
	}
	
	public Employee getAuxiliar() {
		return auxiliar;
	}
	public void setAuxiliar(Employee auxiliar) {
		this.auxiliar = auxiliar;
	}
	
	public Animal getAnimal() {
		return animal;
	}
	public void setAnimal(Animal animal) {
		this.animal = animal;
	}

	public boolean isNotified() {
		return notified;
	}


	public Date getDateProcedure() {
		return dateProcedure;
	}


	public void setDateProcedure(Date dateProcedure) {
		this.dateProcedure = dateProcedure;
	}
	
	public String toStringDate() {
		return this.getDateProcedure().getDay() + "/" + this.getDateProcedure().getMonth() + "/" + this.getDateProcedure().getYear() + " at " + 
				this.getDateProcedure().getHours() + ":" + this.getDateProcedure().getMinutes();
	}
	
	@Override
	public void setStatus(boolean status) {
		this.notified = status;
		this.notifyObservers();
	}
	
	@Override
	public void notifyObservers() {
		Iterator it = this.observers.iterator();
		while(it.hasNext()) {
			Observer observer = (Observer) it.next();
			observer.updateObserver(this);
		}
	}

}
